@@ -7,7 +7,7 @@
 use strict;
 use lib '../../lib';
 
-use OpenFrame::Config;
+use OpenFrame;
 use OpenFrame::Server::HTTP;
 
 my $config = OpenFrame::Config->new();
@@ -16,7 +16,7 @@ $config->setKey(
                 [
                  {
                   dispatch => 'Local',
-                  name => 'OpenFrame::Slot::Images',
+                  name     => 'OpenFrame::Slot::Images',
 		  config   => { directory => './' },
                  },
                  {
@@ -36,11 +36,11 @@ $config->setKey(
 		  config   => {
 			       installed_applications => [
 							  {
-							   name      => 'hangman',
+							   namespace => 'hangman',
 							   uri       => '/',
 							   dispatch  => 'Local',
-							   namespace => 'Hangman::Application',
-							   config   => { words => "./words.txt" },
+							   name      => 'Hangman::Application',
+							   config    => { words => "./words.txt" },
 
 							  },
 							 ],
@@ -83,7 +83,7 @@ Leon Brocard <leon@fotango.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2001, Fotango Ltd.
+Copyright (C) 2001-2, Fotango Ltd.
 
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
