@@ -3,7 +3,7 @@
 use strict;
 use lib '../../lib';
 
-use OpenFrame::Config;
+use OpenFrame;
 use OpenFrame::Server::HTTP;
 
 my $config = OpenFrame::Config->new();
@@ -54,7 +54,7 @@ Leon Brocard <leon@fotango.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2001, Fotango Ltd.
+Copyright (C) 2001-2, Fotango Ltd.
 
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
