@@ -5,7 +5,18 @@ use strict;
 use Exporter;
 use base qw ( Exporter );
 
-our @EXPORT = qw ( ofOK ofDECLINED ofREDIRECT ofERROR );
+our @EXPORT = qw( ofOK ofDECLINED ofREDIRECT ofERROR );
+our @DEBUG  = qw( ofDEBUG_VERBOSE ofDEBUG_CONFIG ofDEBUG_STORE 
+		  ofDEBUG_SLOT ofDEBUG_SESSION ofDEBUG_APPLICATION 
+		  ofDEBUG_GENERATOR ofDEBUG_DISPATCH ofDEBUG_IMAGES 
+		  ofDEBUG_SLOTS ofDEBUG_ALL );
+ 
+our @EXPORT_OK   = ( @EXPORT, @DEBUG );
+our %EXPORT_TAGS = (
+    'all'        => [ @EXPORT_OK ],
+    'debug'      => [ @DEBUG     ],
+);
+
 
 ##
 ## constants for messages in OpenFrame
@@ -15,6 +26,23 @@ use constant ofDECLINED => 2;
 use constant ofREDIRECT => 3;
 use constant ofERROR    => 4;
 
+##
+## debug constants
+##
+use constant ofDEBUG_VERBOSE     =>    1;
+use constant ofDEBUG_CONFIG      =>    2;
+use constant ofDEBUG_STORE       =>    4;
+use constant ofDEBUG_SLOT        =>    8;
+use constant ofDEBUG_SESSION     =>   16;
+use constant ofDEBUG_APPLICATION =>   32;
+use constant ofDEBUG_GENERATOR   =>   64;
+use constant ofDEBUG_DISPATCH    =>  128;
+use constant ofDEBUG_IMAGES      =>  256;
+use constant ofDEBUG_SLOTS       =>  512;
+
+use constant ofDEBUG_ALL         => 1023;
+
+
 1;
 
 __END__
