@@ -4,8 +4,12 @@ use strict;
 
 use Data::Dumper;
 use OpenFrame::Slot;
+use OpenFrame::Constants qw( :debug );
 use base qw ( OpenFrame::Slot );
 
+our $DEBUG = ($OpenFrame::DEBUG || 0) & ofDEBUG_SESSION;
+*warn = \&OpenFrame::warn;
+
 sub what {
   return ['OpenFrame::Session', 'OpenFrame::Request', 'Cache::FileCache'];
 }
@@ -18,15 +22,12 @@ sub action {
   my $cache = shift;
   my $dir = $config->{directory};
 
+  $DEBUG = ($OpenFrame::DEBUG || 0) & ofDEBUG_SESSION;
 
-  my $params = $session->{system}->{parameters};
-  foreach my $key (keys %{$params}) {
-      if (ref($params->{$key}) eq 'GLOB') {
-	  delete $params->{$key};
-      }
-  }
+  # Parameters don't need to be saved
+  delete $session->{system}->{parameters};
 
-  warn("[slot::sessionsaver] saving $session") if $OpenFrame::DEBUG;
+  &warn("saving $session") if $DEBUG;
   my $cookietin = $request->cookies();
   my $id = $cookietin->get("session");
   $cache->set($id, $session);
