@@ -1,13 +1,13 @@
 package OpenFrame::Slot::SimpleGenerator;
 
 use strict;
-use Data::Dumper;
+use Storable qw(dclone);
 use OpenFrame::Config;
-use OpenFrame::AbstractResponse;
+use OpenFrame::Response;
 use OpenFrame::Constants;
 
 sub what {
-  return ['OpenFrame::Session', 'OpenFrame::AbstractRequest', 'OpenFrame::AbstractCookie'];
+  return ['OpenFrame::Session', 'OpenFrame::Request', 'OpenFrame::Cookietin'];
 }
 
 sub action {
@@ -17,13 +17,9 @@ sub action {
   my $request   = shift;
   my $cookietin = shift;
 
-  my $output;
-
-  my $response = OpenFrame::AbstractResponse->new();
-
-  my $sessioncopy;
-  eval Data::Dumper->Dump([$session], ["sessioncopy"]);
+  my $sessioncopy = dclone($session);
 
+  my $response = OpenFrame::Response->new();
   $response->message($sessioncopy);
   $response->code(ofOK);
   $response->mimetype('openframe/session');
@@ -59,7 +55,7 @@ Leon Brocard <leon@fotango.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2001, Fotango Ltd.
+Copyright (C) 2001-2, Fotango Ltd.
 
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
